@@ -5,6 +5,13 @@ from jira_commonmark.parser import Jira2CommonMarkParser, Jira2HtmlParser, Jira2
 
 
 def jira_to_html(jira_text: str, url_base: str=None, internal_hosts: list=None) -> str:
+    """ Jira -> Html converter
+
+    :param jira_text: text
+    :param url_base:
+    :param internal_hosts:
+    :return:
+    """
     handler = HTMLRenderer(
          url_base=url_base,
          internal_hosts=internal_hosts
