@@ -37,7 +37,7 @@ class EmailConverter(Converter):
 
 class UrlConverter(Converter):
 
-    pattern = r"(?<!href=)(?<!]\()(?<!\>)(?<!\[)(((?<!\/\/)www|https?:\/\/))[\.\%\w0-9\/\-\?\=\:\+\&]+\w"
+    pattern = r"(?<!href=)(?<!]\()(?<!\>)(?<!\[)(((?<!\/\/)www|https?:\/\/))[\.\%\w0-9\/\-\?\=\:\+\&\(\)]+\w"
 
     @classmethod
     def convert(cls, text: str, handler: Handler) -> str:
@@ -48,7 +48,7 @@ class UrlConverter(Converter):
 
 class JiraUrlConverter(Converter):
 
-    pattern = r"\[\s*([^\s]+[\w,;\.\-\(\)\sæøå]*[\w,;\.\-\(\)æøå])\s*\|\s*(www|http:|https:+[^\s]+[\w,;])\s*\]"
+    pattern = r"\[\s*([^\s]+[\w,;\.\-\(\)\sæøåÆØÅ§]*[\w,;\.\-\(\)æøåÆØÅ§\/])\s*\|\s*(www|http:|https:+[^\s]+[\w,;\/])\s*\]"
 
     @classmethod
     def convert(cls, text: str, handler: Handler) -> str:
@@ -59,7 +59,7 @@ class JiraUrlConverter(Converter):
 
 class JiraExpressionConverter(Converter):
 
-    pattern = r"{\.\.\.}|\[\.\.\.\]|{\s*color(\s*:\s*#\w*)?\s*}"
+    pattern = r"{\.\.\.}\s*|\[\.\.\.\]\s*|{\s*color(\s*:\s*#\w*)?\s*}\s*"
 
     @classmethod
     def convert(cls, text: str, handler: Handler) -> str:
@@ -69,7 +69,7 @@ class JiraExpressionConverter(Converter):
 
 class TextInBracketsConverter(Converter):
 
-    pattern = r"\[([\w\s\:\/\-\.]+)\](?!\()"
+    pattern = r"\[([\w\s\:\/\-\.\?\=\&]+)\](?!\()"
 
     @classmethod
     def convert(cls, text: str, handler: Handler) -> str:
