@@ -1,5 +1,6 @@
 import re
 from abc import ABC
+from urllib3 import util
 
 
 class Handler(ABC):
@@ -7,8 +8,12 @@ class Handler(ABC):
     Handles calls from parser
     """
 
-    def __init__(self, url_base: str=None):
+    def __init__(self, url_base: str=None, internal_hosts: list=None):
         self.url_base = url_base
+        if not internal_hosts:
+            self.internal_hosts = []
+        else:
+            self.internal_hosts = internal_hosts
 
     def line_feed(self):
         raise NotImplementedError()
@@ -30,3 +35,10 @@ class Handler(ABC):
 
     def sub_brackets(self, match):
         return re.sub(r"[\[\]]", '', match.group(0))
+
+    def _is_internal_address(self, url):
+        host = util.parse_url(url).host
+        for internal_host in self.internal_hosts:
+            if internal_host in host:
+                return True
+        return False
