@@ -25,7 +25,10 @@ class TextRenderer(Handler):
         return f"{match.group()}"
 
     def sub_jira_url(self, match):
-        return f"{match.group(1)}"
+        if match.group(1) == match.group(2):
+            return f"{match.group(1)}"
+        else:
+            return f"{match.group(1)}: {match.group(2)}"
 
     def sub_link(self, match):
         return f"{match.group(1)}"
